//
//      leibnitz.cpp - Compute pi by the Leibnitz expansion,
//                   which is obtained from
//
//		Int(0 to x)[ 1/(1 + x**2)]dx = arctan(x)
//
//         by setting x = 1, so that  arctan(x) = pi/4:
//
//          pi = 4( 1 - 1/3 + 1/5 - 1/7 +....)
//
//             = 4*Sum(n=0 thru N=infinity) of [1/(2n+1)][(-1)**(n)].
//
//         The Leibnitz series is slowly converging and mainly
//		interesting for the factor of 4 as a first term,
//              which we may compare with the factor of 3 in
//              Newton's rapidly converging series for pi.
//                      
//                      - Author: James A. Green, who derived the
//					expression for the mth term.
//			- Compiler: Borland C/C++
//
//
#include <stdio.h>
#include <math.h>
#include <string.h>
#include <stdlib.h>
main()
{
	double pi0 = 3.141592653589793;
//the known value of pi.
	double pival; // computed pi value = 3 + term(0) + term(1) +..

	double term(int m); // mth term in series expansion for pi.
	double termx;
        double sign;
	int n;		// index of the last term in the pi expansion.
	int more = 1;
	int i;

     while(more == 1){
	printf("Leibnitz - Compute pi via the Leibnitz Series,\n");
	printf("  Uses arctan(x) = (1 - x**3/3 + x**5/5 - x**7/7 +... \n");
	printf("  for arctan(1) = pi/4, so that\n");
	printf("  pi = 4 arctan(1)\n");
	printf("     = 4*(1 - 1/3 + 1/5 - 1/7 + 1/9 - .....\n");
	printf("      \n");
	printf("  Use N terms in the expansion.\n");
	printf("      \n");  
	printf("Enter N < 32000, to compute N terms in the expansion:");
	scanf("%d",&n);
	printf("\n");
	if(n < 0){
	   printf("N may not be less than zero.");
	   exit(0);
	}

	pival = 0.0;	// 0 is the root for pi expansion.
	sign = +1;
	for(i=0; i < n; i++){
        	termx = term(i);
		pival = pival + (sign*termx);
                sign = sign*(-1.0);
        }
        printf("  PI_value[for first %d terms] = %1.30f\n",n, pival);
	
	printf("Known pi = %1.15f \n",pi0);

     	printf("Enter 1 to continue or 0 to exit:");
	scanf("%d", &more);
	printf("\n");
	if(more == 0) exit;
     }
     printf("End Leibnitz, Calculation of pi via the method of\n");
     printf("            Gottfried Leibnitz.\n\n");

}
//
// term(m) =
//
//   4*[1/(2m+1)].  Manage the sign of the term in the host.
//
double term(int m)
{
	int i;
	double tm;
        double vm;
	double quo;

	double denom;

        vm = m;
	denom = (2.0*vm) + 1;
	
	tm = 4.0*(1/denom);
	
        return(tm);
}



































































































































































































































































































































































































































































































